# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 4.5.7 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class CoreCourseGetContentsResponseInner(BaseModel):
    """
    CoreCourseGetContentsResponseInner
    """ # noqa: E501
    availabilityinfo: Optional[StrictStr] = Field(default=None, description="Availability information.")
    component: Optional[StrictStr] = Field(default=None, description="The delegate component of this section if any.")
    hiddenbynumsections: Optional[StrictInt] = Field(default=None, description="Whether is a section hidden in the course format")
    id: Optional[StrictInt] = Field(description="Section ID")
    itemid: Optional[StrictInt] = Field(default=None, description="The optional item id delegate component can use to identify its instance.")
    modules: List[CoreCourseGetContentsResponseInnerModulesInner] = Field(description="list of module")
    name: Optional[StrictStr] = Field(description="Section name")
    section: Optional[StrictInt] = Field(default=None, description="Section number inside the course")
    summary: Optional[StrictStr] = Field(description="Section description")
    summaryformat: Optional[StrictInt] = Field(description="summary format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    uservisible: Optional[StrictBool] = Field(default=None, description="Is the section visible for the user?")
    visible: Optional[StrictInt] = Field(default=None, description="is the section visible")
    __properties: ClassVar[List[str]] = ["availabilityinfo", "component", "hiddenbynumsections", "id", "itemid", "modules", "name", "section", "summary", "summaryformat", "uservisible", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in modules (list)
        _items = []
        if self.modules:
            for _item_modules in self.modules:
                if _item_modules:
                    _items.append(_item_modules.to_dict())
            _dict['modules'] = _items
        # set to None if availabilityinfo (nullable) is None
        # and model_fields_set contains the field
        if self.availabilityinfo is None and "availabilityinfo" in self.model_fields_set:
            _dict['availabilityinfo'] = None

        # set to None if component (nullable) is None
        # and model_fields_set contains the field
        if self.component is None and "component" in self.model_fields_set:
            _dict['component'] = None

        # set to None if hiddenbynumsections (nullable) is None
        # and model_fields_set contains the field
        if self.hiddenbynumsections is None and "hiddenbynumsections" in self.model_fields_set:
            _dict['hiddenbynumsections'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if itemid (nullable) is None
        # and model_fields_set contains the field
        if self.itemid is None and "itemid" in self.model_fields_set:
            _dict['itemid'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if section (nullable) is None
        # and model_fields_set contains the field
        if self.section is None and "section" in self.model_fields_set:
            _dict['section'] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict['summary'] = None

        # set to None if summaryformat (nullable) is None
        # and model_fields_set contains the field
        if self.summaryformat is None and "summaryformat" in self.model_fields_set:
            _dict['summaryformat'] = None

        # set to None if uservisible (nullable) is None
        # and model_fields_set contains the field
        if self.uservisible is None and "uservisible" in self.model_fields_set:
            _dict['uservisible'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsResponseInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCourseGetContentsResponseInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "availabilityinfo": obj.get("availabilityinfo"),
            "component": obj.get("component"),
            "hiddenbynumsections": obj.get("hiddenbynumsections"),
            "id": obj.get("id"),
            "itemid": obj.get("itemid"),
            "modules": [CoreCourseGetContentsResponseInnerModulesInner.from_dict(_item) for _item in obj["modules"]] if obj.get("modules") is not None else None,
            "name": obj.get("name"),
            "section": obj.get("section"),
            "summary": obj.get("summary"),
            "summaryformat": obj.get("summaryformat"),
            "uservisible": obj.get("uservisible"),
            "visible": obj.get("visible")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 4.5.7 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class CoreCommentAddCommentsResponseInner(BaseModel):
    """
    comment
    """ # noqa: E501
    avatar: Optional[StrictStr] = Field(description="HTML user picture")
    content: Optional[StrictStr] = Field(description="The content text formatted")
    delete: Optional[StrictBool] = Field(default=None, description="Permission to delete=true/false")
    format: Optional[StrictInt] = Field(description="content format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    fullname: Optional[StrictStr] = Field(description="fullname")
    id: Optional[StrictInt] = Field(description="Comment ID")
    profileurl: Optional[StrictStr] = Field(description="URL profile")
    strftimeformat: Optional[StrictStr] = Field(description="Time format")
    time: Optional[StrictStr] = Field(description="Time in human format")
    timecreated: Optional[StrictInt] = Field(description="Time created (timestamp)")
    userid: Optional[StrictInt] = Field(description="User ID")
    __properties: ClassVar[List[str]] = ["avatar", "content", "delete", "format", "fullname", "id", "profileurl", "strftimeformat", "time", "timecreated", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCommentAddCommentsResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if delete (nullable) is None
        # and model_fields_set contains the field
        if self.delete is None and "delete" in self.model_fields_set:
            _dict['delete'] = None

        # set to None if format (nullable) is None
        # and model_fields_set contains the field
        if self.format is None and "format" in self.model_fields_set:
            _dict['format'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if profileurl (nullable) is None
        # and model_fields_set contains the field
        if self.profileurl is None and "profileurl" in self.model_fields_set:
            _dict['profileurl'] = None

        # set to None if strftimeformat (nullable) is None
        # and model_fields_set contains the field
        if self.strftimeformat is None and "strftimeformat" in self.model_fields_set:
            _dict['strftimeformat'] = None

        # set to None if time (nullable) is None
        # and model_fields_set contains the field
        if self.time is None and "time" in self.model_fields_set:
            _dict['time'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCommentAddCommentsResponseInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCommentAddCommentsResponseInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "avatar": obj.get("avatar"),
            "content": obj.get("content"),
            "delete": obj.get("delete"),
            "format": obj.get("format"),
            "fullname": obj.get("fullname"),
            "id": obj.get("id"),
            "profileurl": obj.get("profileurl"),
            "strftimeformat": obj.get("strftimeformat"),
            "time": obj.get("time"),
            "timecreated": obj.get("timecreated"),
            "userid": obj.get("userid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 4.5.7 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner(BaseModel):
    """
    submission info
    """ # noqa: E501
    assignment: Optional[StrictInt] = Field(default=None, description="assignment id")
    attemptnumber: Optional[StrictInt] = Field(description="attempt number")
    gradingstatus: Optional[StrictStr] = Field(default=None, description="Grading status.")
    groupid: Optional[StrictInt] = Field(description="group id")
    id: Optional[StrictInt] = Field(description="submission id")
    latest: Optional[StrictInt] = Field(default=None, description="latest attempt")
    plugins: Optional[List[ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner]] = Field(default=None, description="plugins")
    status: Optional[StrictStr] = Field(description="submission status")
    timecreated: Optional[StrictInt] = Field(description="submission creation time")
    timemodified: Optional[StrictInt] = Field(description="submission last modified time")
    timestarted: Optional[StrictInt] = Field(default=None, description="submission start time")
    userid: Optional[StrictInt] = Field(description="student id")
    __properties: ClassVar[List[str]] = ["assignment", "attemptnumber", "gradingstatus", "groupid", "id", "latest", "plugins", "status", "timecreated", "timemodified", "timestarted", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in plugins (list)
        _items = []
        if self.plugins:
            for _item_plugins in self.plugins:
                if _item_plugins:
                    _items.append(_item_plugins.to_dict())
            _dict['plugins'] = _items
        # set to None if assignment (nullable) is None
        # and model_fields_set contains the field
        if self.assignment is None and "assignment" in self.model_fields_set:
            _dict['assignment'] = None

        # set to None if attemptnumber (nullable) is None
        # and model_fields_set contains the field
        if self.attemptnumber is None and "attemptnumber" in self.model_fields_set:
            _dict['attemptnumber'] = None

        # set to None if gradingstatus (nullable) is None
        # and model_fields_set contains the field
        if self.gradingstatus is None and "gradingstatus" in self.model_fields_set:
            _dict['gradingstatus'] = None

        # set to None if groupid (nullable) is None
        # and model_fields_set contains the field
        if self.groupid is None and "groupid" in self.model_fields_set:
            _dict['groupid'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if latest (nullable) is None
        # and model_fields_set contains the field
        if self.latest is None and "latest" in self.model_fields_set:
            _dict['latest'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if timestarted (nullable) is None
        # and model_fields_set contains the field
        if self.timestarted is None and "timestarted" in self.model_fields_set:
            _dict['timestarted'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "assignment": obj.get("assignment"),
            "attemptnumber": obj.get("attemptnumber"),
            "gradingstatus": obj.get("gradingstatus"),
            "groupid": obj.get("groupid"),
            "id": obj.get("id"),
            "latest": obj.get("latest"),
            "plugins": [ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner.from_dict(_item) for _item in obj["plugins"]] if obj.get("plugins") is not None else None,
            "status": obj.get("status"),
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "timestarted": obj.get("timestarted"),
            "userid": obj.get("userid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


